Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src\attipy\__init__.py | (no class) | 2 | 0 | 0 | 0 | 0 | 100%
src\attipy\_attitude.py | Attitude | 18 | 1 | 0 | 4 | 0 | 95%
src\attipy\_attitude.py | (no class) | 34 | 5 | 0 | 10 | 5 | 77%
src\attipy\_transforms.py | (no class) | 102 | 88 | 0 | 6 | 0 | 13%
src\attipy\_vectorops.py | (no class) | 11 | 4 | 0 | 0 | 0 | 64%
Total |  | 167 | 98 | 0 | 20 | 5 | 42%

No items found using the specified filter.